#[non_exhaustive]pub struct ListCalculationExecutionsInput {
pub session_id: Option<String>,
pub state_filter: Option<CalculationExecutionState>,
pub max_results: Option<i32>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.session_id: Option<String>The session ID.
state_filter: Option<CalculationExecutionState>A filter for a specific calculation execution state. A description of each state follows.
CREATING - The calculation is in the process of being created.
CREATED - The calculation has been created and is ready to run.
QUEUED - The calculation has been queued for processing.
RUNNING - The calculation is running.
CANCELING - A request to cancel the calculation has been received and the system is working to stop it.
CANCELED - The calculation is no longer running as the result of a cancel request.
COMPLETED - The calculation has completed without error.
FAILED - The calculation failed and is no longer running.
max_results: Option<i32>The maximum number of calculation executions to return.
next_token: Option<String>A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Implementations
Sourceimpl ListCalculationExecutionsInput
impl ListCalculationExecutionsInput
Sourcepub fn session_id(&self) -> Option<&str>
pub fn session_id(&self) -> Option<&str>
The session ID.
Sourcepub fn state_filter(&self) -> Option<&CalculationExecutionState>
pub fn state_filter(&self) -> Option<&CalculationExecutionState>
A filter for a specific calculation execution state. A description of each state follows.
CREATING - The calculation is in the process of being created.
CREATED - The calculation has been created and is ready to run.
QUEUED - The calculation has been queued for processing.
RUNNING - The calculation is running.
CANCELING - A request to cancel the calculation has been received and the system is working to stop it.
CANCELED - The calculation is no longer running as the result of a cancel request.
COMPLETED - The calculation has completed without error.
FAILED - The calculation failed and is no longer running.
Sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
The maximum number of calculation executions to return.
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourceimpl ListCalculationExecutionsInput
impl ListCalculationExecutionsInput
Sourcepub fn builder() -> ListCalculationExecutionsInputBuilder
pub fn builder() -> ListCalculationExecutionsInputBuilder
Creates a new builder-style object to manufacture ListCalculationExecutionsInput.