#[non_exhaustive]pub struct ListCalculationExecutionsOutput {
pub next_token: Option<String>,
pub calculations: Option<Vec<CalculationSummary>>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.next_token: Option<String>A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
calculations: Option<Vec<CalculationSummary>>A list of CalculationSummary objects.
Implementations
Sourceimpl ListCalculationExecutionsOutput
impl ListCalculationExecutionsOutput
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn calculations(&self) -> &[CalculationSummary]
pub fn calculations(&self) -> &[CalculationSummary]
A list of CalculationSummary objects.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .calculations.is_none().
Sourceimpl ListCalculationExecutionsOutput
impl ListCalculationExecutionsOutput
Sourcepub fn builder() -> ListCalculationExecutionsOutputBuilder
pub fn builder() -> ListCalculationExecutionsOutputBuilder
Creates a new builder-style object to manufacture ListCalculationExecutionsOutput.